# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx

from ...types.lb import (
    highlvl_get_full_tg_list_params,
    highlvl_get_tg_names_only_params,
    highlvl_create_target_group_params,
    highlvl_delete_target_group_params,
    highlvl_update_target_group_params,
    highlvl_update_load_balancer_params,
    highlvl_get_detailed_target_groups_params,
    highlvl_create_load_balancer_orchestration_params
)
from ...types.lb.highlvl_create_target_group_response import TargetGroupCreateResponse   
from ...types.lb.highlvl_create_lb_orchestration_response import LBOrchestrationResp


from ..._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven,Omit, omit
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options

__all__ = ["HighlvlResource", "AsyncHighlvlResource"]


class HighlvlResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> HighlvlResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/lb2-python#accessing-raw-response-data-eg-headers
        """
        return HighlvlResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> HighlvlResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/lb2-python#with_streaming_response
        """
        return HighlvlResourceWithStreamingResponse(self)
    


    def validate_region(self, x_region: str) -> None:
        if not x_region.strip():
            raise ValueError("'x_region' must be a non-empty string.")
        if x_region not in ('In-Bangalore-1'):
            raise ValueError(
                f"Invalid region '{x_region}'. Supported regions are: 'In-Bangalore-1'."
            )

    def create_load_balancer_orchestration(
        self,
        *,
        k_customer_id: str,
        x_account_id: str,
        x_region: str,
        listeners: Iterable[object] | Omit = omit,
        loadbalancer_data: object | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> LBOrchestrationResp:
        """
        Create Load Balancer Orchestration

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"k-customer-id": k_customer_id, "x-account-id": x_account_id, "x-region": x_region})
        return self._post(
            "/v3/highlvl/create_load_balancer_orchestration",
            body=maybe_transform(
                {
                    "listeners": listeners,
                    "loadbalancer_data": loadbalancer_data,
                },
                highlvl_create_load_balancer_orchestration_params.HighlvlCreateLoadBalancerOrchestrationParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=LBOrchestrationResp,
        )

    def create_target_group(
        self,
        *,
        x_region: str,
        health_monitor: highlvl_create_target_group_params.HealthMonitor | Omit = omit,
        members: Iterable[highlvl_create_target_group_params.Member] | Omit = omit,
        target_group_name: str | Omit = omit,
        vpc_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TargetGroupCreateResponse:
        """
        Create Target Group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return self._post(
            "/v1/highlvl/create_target_group",
            body=maybe_transform(
                {
                    "health_monitor": health_monitor,
                    "members": members,
                    "target_group_name": target_group_name,
                    "vpc_id": vpc_id,
                },
                highlvl_create_target_group_params.HighlvlCreateTargetGroupParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TargetGroupCreateResponse,
        )

    def delete_load_balancer(
        self,
        lb_krn: str,
        *,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Load Balancer

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        if not lb_krn:
            raise ValueError(f"Expected a non-empty value for `lb_krn` but received {lb_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return self._delete(
            f"/v3/highlvl/loadbalancer/{lb_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def delete_target_group(
        self,
        *,
        target_group_name: str,
        vpc_id: str,
        x_region:str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Target Group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return self._delete(
            "/v1/highlvl/target_group",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "target_group_name": target_group_name,
                        "vpc_id": vpc_id,
                    },
                    highlvl_delete_target_group_params.HighlvlDeleteTargetGroupParams,
                ),
            ),
            cast_to=NoneType,
        )

    def fetch_payload_multiple(
        self,
        lb_krn: str,
        x_region:str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Fetch Detailed LB Payload

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        if not lb_krn:
            raise ValueError(f"Expected a non-empty value for `lb_krn` but received {lb_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return self._get(
            f"/v3/highlvl/fetch_payload_multiple/{lb_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def get_detailed_target_groups(
        self,
        *,
        k_customer_id: str,
        x_account_id: str,
        x_region: str,
        vpc_id: str,
        target_group_name: str | Omit = omit,
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update(
            {
                "k-customer-id": k_customer_id,
                "x-account-id": x_account_id,
                "x-region": x_region,
            }
        )

        return self._get(
            "/v1/highlvl/get_target_groups",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"vpc_id": vpc_id, "target_group_name": target_group_name},
                    highlvl_get_detailed_target_groups_params.HighlvlGetDetailedTargetGroupsParams,
                ),
            ),
            cast_to=NoneType,
        )


    def get_full_tg_list(
        self,
        *,
        vpc_id: str,
        x_region:str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get Full TG List

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return self._get(
            "/v1/highlvl/get_tg_list",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"vpc_id": vpc_id}, highlvl_get_full_tg_list_params.HighlvlGetFullTgListParams),
            ),
            cast_to=NoneType,
        )

    def get_task_status(
        self,
        task_id: str,
        x_region:str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get Task Status

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region}) 
        return self._get(
            f"/v3/highlvl/task_status/{task_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )

    def get_tg_names_only(
        self,
        *,
        vpc_id: str,
        x_region:str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get TG Names Only

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region}) 
        return self._get(
            "/v1/highlvl/get_target_group_names",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"vpc_id": vpc_id}, highlvl_get_tg_names_only_params.HighlvlGetTgNamesOnlyParams),
            ),
            cast_to=NoneType,
        )

    def list_load_balancers_by_vpc(
        self,
        vpc_krn: str,
        x_region:str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        List Load Balancers by VPC

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        if not vpc_krn:
            raise ValueError(f"Expected a non-empty value for `vpc_krn` but received {vpc_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region}) 
        return self._get(
            f"/v3/highlvl/get_lb_list_new/{vpc_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update_load_balancer(
        self,
        path_lb_krn: str,
        *,
        x_region: str,
        k_customer_id: str,
        x_account_id: str,
        listeners: Iterable[object] | Omit = omit,
        loadbalancer_data: object | Omit = omit,
        security_groups: Iterable[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Update Load Balancer

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        if not path_lb_krn:
            raise ValueError(f"Expected a non-empty value for `path_lb_krn` but received {path_lb_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"k-customer-id": k_customer_id, "x-account-id": x_account_id, "x-region": x_region})
        payload: dict = {
            "lb_krn": path_lb_krn,
        }
        if listeners is not omit:
            payload["listeners"] = listeners
        if loadbalancer_data is not omit:
            payload["loadbalancer_data"] = loadbalancer_data
        if security_groups is not omit:
            payload["security_groups"] = list(security_groups)               
        return self._post(
            f"/v3/highlvl/update_load_balancer/{path_lb_krn}",
            body=payload,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update_target_group(
        self,
        *,
        x_region: str,
        k_customer_id: str,
        x_account_id: str,
        health_monitor: highlvl_update_target_group_params.HealthMonitor | Omit = omit,
        members: Iterable[highlvl_update_target_group_params.Member] | Omit = omit,
        target_group_name: str | Omit = omit,
        vpc_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Update Target Group Members/Health

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update(
            {
                "k-customer-id": k_customer_id,
                "x-account-id": x_account_id,
                "x-region": x_region,
            }
        )
        return self._post(
            "/v1/highlvl/updatetg",
            body=maybe_transform(
                {
                    "health_monitor": health_monitor,
                    "members": members,
                    "target_group_name": target_group_name,
                    "vpc_id": vpc_id,
                },
                highlvl_update_target_group_params.HighlvlUpdateTargetGroupParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncHighlvlResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncHighlvlResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/stainless-sdks/lb2-python#accessing-raw-response-data-eg-headers
        """
        return AsyncHighlvlResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncHighlvlResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/stainless-sdks/lb2-python#with_streaming_response
        """
        return AsyncHighlvlResourceWithStreamingResponse(self)
    async def validate_region(x_region: str) -> None:
        if not isinstance(x_region, str) or not x_region.strip():
            raise ValueError("'x_region' must be a non-empty string.")
        if x_region not in ('In-Bangalore-1'):
            raise ValueError(
                f"Invalid region '{x_region}'. Supported regions are: 'In-Bangalore-1'."
            )

    async def create_load_balancer_orchestration(
        self,
        *,
        k_customer_id: str,
        x_account_id: str,
        x_region: str,
        listeners: Iterable[object] | Omit = omit,
        loadbalancer_data: object | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Load Balancer Orchestration

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"k-customer-id": k_customer_id, "x-account-id": x_account_id, "x-region": x_region})
        return await self._post(
            "/v3/highlvl/create_load_balancer_orchestration",
            body=await async_maybe_transform(
                {
                    "listeners": listeners,
                    "loadbalancer_data": loadbalancer_data,
                },
                highlvl_create_load_balancer_orchestration_params.HighlvlCreateLoadBalancerOrchestrationParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def create_target_group(
        self,
        *,
        x_region: str,
        health_monitor: highlvl_create_target_group_params.HealthMonitor | Omit = omit,
        members: Iterable[highlvl_create_target_group_params.Member] | Omit = omit,
        target_group_name: str | Omit = omit,
        vpc_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Create Target Group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return await self._post(
            "/v1/highlvl/create_target_group",
            body=await async_maybe_transform(
                {
                    "health_monitor": health_monitor,
                    "members": members,
                    "target_group_name": target_group_name,
                    "vpc_id": vpc_id,
                },
                highlvl_create_target_group_params.HighlvlCreateTargetGroupParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete_load_balancer(
        self,
        lb_krn: str,
        *,
        x_region: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Load Balancer

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_region(x_region)
        if not lb_krn:
            raise ValueError(f"Expected a non-empty value for `lb_krn` but received {lb_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return await self._delete(
            f"/v3/highlvl/loadbalancer/{lb_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def delete_target_group(
        self,
        *,
        target_group_name: str,
        vpc_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete Target Group

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            "/v1/highlvl/target_group",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "target_group_name": target_group_name,
                        "vpc_id": vpc_id,
                    },
                    highlvl_delete_target_group_params.HighlvlDeleteTargetGroupParams,
                ),
            ),
            cast_to=NoneType,
        )

    async def fetch_payload_multiple(
        self,
        lb_krn: str,
        x_region:str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Fetch Detailed LB Payload

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_region(x_region)
        if not lb_krn:
            raise ValueError(f"Expected a non-empty value for `lb_krn` but received {lb_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region})
        return await self._get(
            f"/v3/highlvl/fetch_payload_multiple/{lb_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_detailed_target_groups(
        self,
        *,
        vpc_id: str,
        x_region:str,
        target_group_name: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get Detailed Target Groups

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region}) 
        return await self._get(
            "/v1/highlvl/get_target_groups",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "vpc_id": vpc_id,
                        "target_group_name": target_group_name,
                    },
                    highlvl_get_detailed_target_groups_params.HighlvlGetDetailedTargetGroupsParams,
                ),
            ),
            cast_to=NoneType,
        )

    async def get_full_tg_list(
        self,
        *,
        vpc_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get Full TG List

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/v1/highlvl/get_tg_list",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"vpc_id": vpc_id}, highlvl_get_full_tg_list_params.HighlvlGetFullTgListParams
                ),
            ),
            cast_to=NoneType,
        )

    async def get_task_status(
        self,
        task_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get Task Status

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not task_id:
            raise ValueError(f"Expected a non-empty value for `task_id` but received {task_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            f"/v3/highlvl/task_status/{task_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def get_tg_names_only(
        self,
        *,
        vpc_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Get TG Names Only

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._get(
            "/v1/highlvl/get_target_group_names",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"vpc_id": vpc_id}, highlvl_get_tg_names_only_params.HighlvlGetTgNamesOnlyParams
                ),
            ),
            cast_to=NoneType,
        )

    async def list_load_balancers_by_vpc(
        self,
        vpc_krn: str,
        x_region:str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        List Load Balancers by VPC

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_region(x_region)
        if not vpc_krn:
            raise ValueError(f"Expected a non-empty value for `vpc_krn` but received {vpc_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"x-region": x_region}) 
        return await self._get(
            f"/v3/highlvl/get_lb_list_new/{vpc_krn}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update_load_balancer(
        self,
        path_lb_krn: str,
        *,
        x_region: str,
        k_customer_id: str,
        x_account_id: str,
        listeners: Iterable[object] | Omit = omit,
        loadbalancer_data: object | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Update Load Balancer

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_region(x_region)
        if not path_lb_krn:
            raise ValueError(f"Expected a non-empty value for `path_lb_krn` but received {path_lb_krn!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update({"k-customer-id": k_customer_id, "x-account-id": x_account_id, "x-region": x_region})
        payload: dict = {
            "lb_krn": path_lb_krn,
        }
        if listeners is not omit:
            payload["listeners"] = listeners
        if loadbalancer_data is not omit:
            payload["loadbalancer_data"] = loadbalancer_data
        return await self._post(
            f"/v3/highlvl/update_load_balancer/{path_lb_krn}",
            body=payload,
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update_target_group(
        self,
        *,
        x_region: str,
        k_customer_id: str,
        x_account_id: str,
        health_monitor: highlvl_update_target_group_params.HealthMonitor | Omit = omit,
        members: Iterable[highlvl_update_target_group_params.Member] | Omit = omit,
        target_group_name: str | Omit = omit,
        vpc_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Update Target Group Members/Health

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        await self.validate_region(x_region)
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        extra_headers.update(
            {
                "k-customer-id": k_customer_id,
                "x-account-id": x_account_id,
                "x-region": x_region,
            }
        )
        return await self._post(
            "/v1/highlvl/updatetg",
            body=await async_maybe_transform(
                {
                    "health_monitor": health_monitor,
                    "members": members,
                    "target_group_name": target_group_name,
                    "vpc_id": vpc_id,
                },
                highlvl_update_target_group_params.HighlvlUpdateTargetGroupParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class HighlvlResourceWithRawResponse:
    def __init__(self, highlvl: HighlvlResource) -> None:
        self._highlvl = highlvl

        self.create_load_balancer_orchestration = to_raw_response_wrapper(
            highlvl.create_load_balancer_orchestration,
        )
        self.create_target_group = to_raw_response_wrapper(
            highlvl.create_target_group,
        )
        self.delete_load_balancer = to_raw_response_wrapper(
            highlvl.delete_load_balancer,
        )
        self.delete_target_group = to_raw_response_wrapper(
            highlvl.delete_target_group,
        )
        self.fetch_payload_multiple = to_raw_response_wrapper(
            highlvl.fetch_payload_multiple,
        )
        self.get_detailed_target_groups = to_raw_response_wrapper(
            highlvl.get_detailed_target_groups,
        )
        self.get_full_tg_list = to_raw_response_wrapper(
            highlvl.get_full_tg_list,
        )
        self.get_task_status = to_raw_response_wrapper(
            highlvl.get_task_status,
        )
        self.get_tg_names_only = to_raw_response_wrapper(
            highlvl.get_tg_names_only,
        )
        self.list_load_balancers_by_vpc = to_raw_response_wrapper(
            highlvl.list_load_balancers_by_vpc,
        )
        self.update_load_balancer = to_raw_response_wrapper(
            highlvl.update_load_balancer,
        )
        self.update_target_group = to_raw_response_wrapper(
            highlvl.update_target_group,
        )


class AsyncHighlvlResourceWithRawResponse:
    def __init__(self, highlvl: AsyncHighlvlResource) -> None:
        self._highlvl = highlvl

        self.create_load_balancer_orchestration = async_to_raw_response_wrapper(
            highlvl.create_load_balancer_orchestration,
        )
        self.create_target_group = async_to_raw_response_wrapper(
            highlvl.create_target_group,
        )
        self.delete_load_balancer = async_to_raw_response_wrapper(
            highlvl.delete_load_balancer,
        )
        self.delete_target_group = async_to_raw_response_wrapper(
            highlvl.delete_target_group,
        )
        self.fetch_payload_multiple = async_to_raw_response_wrapper(
            highlvl.fetch_payload_multiple,
        )
        self.get_detailed_target_groups = async_to_raw_response_wrapper(
            highlvl.get_detailed_target_groups,
        )
        self.get_full_tg_list = async_to_raw_response_wrapper(
            highlvl.get_full_tg_list,
        )
        self.get_task_status = async_to_raw_response_wrapper(
            highlvl.get_task_status,
        )
        self.get_tg_names_only = async_to_raw_response_wrapper(
            highlvl.get_tg_names_only,
        )
        self.list_load_balancers_by_vpc = async_to_raw_response_wrapper(
            highlvl.list_load_balancers_by_vpc,
        )
        self.update_load_balancer = async_to_raw_response_wrapper(
            highlvl.update_load_balancer,
        )
        self.update_target_group = async_to_raw_response_wrapper(
            highlvl.update_target_group,
        )


class HighlvlResourceWithStreamingResponse:
    def __init__(self, highlvl: HighlvlResource) -> None:
        self._highlvl = highlvl

        self.create_load_balancer_orchestration = to_streamed_response_wrapper(
            highlvl.create_load_balancer_orchestration,
        )
        self.create_target_group = to_streamed_response_wrapper(
            highlvl.create_target_group,
        )
        self.delete_load_balancer = to_streamed_response_wrapper(
            highlvl.delete_load_balancer,
        )
        self.delete_target_group = to_streamed_response_wrapper(
            highlvl.delete_target_group,
        )
        self.fetch_payload_multiple = to_streamed_response_wrapper(
            highlvl.fetch_payload_multiple,
        )
        self.get_detailed_target_groups = to_streamed_response_wrapper(
            highlvl.get_detailed_target_groups,
        )
        self.get_full_tg_list = to_streamed_response_wrapper(
            highlvl.get_full_tg_list,
        )
        self.get_task_status = to_streamed_response_wrapper(
            highlvl.get_task_status,
        )
        self.get_tg_names_only = to_streamed_response_wrapper(
            highlvl.get_tg_names_only,
        )
        self.list_load_balancers_by_vpc = to_streamed_response_wrapper(
            highlvl.list_load_balancers_by_vpc,
        )
        self.update_load_balancer = to_streamed_response_wrapper(
            highlvl.update_load_balancer,
        )
        self.update_target_group = to_streamed_response_wrapper(
            highlvl.update_target_group,
        )


class AsyncHighlvlResourceWithStreamingResponse:
    def __init__(self, highlvl: AsyncHighlvlResource) -> None:
        self._highlvl = highlvl

        self.create_load_balancer_orchestration = async_to_streamed_response_wrapper(
            highlvl.create_load_balancer_orchestration,
        )
        self.create_target_group = async_to_streamed_response_wrapper(
            highlvl.create_target_group,
        )
        self.delete_load_balancer = async_to_streamed_response_wrapper(
            highlvl.delete_load_balancer,
        )
        self.delete_target_group = async_to_streamed_response_wrapper(
            highlvl.delete_target_group,
        )
        self.fetch_payload_multiple = async_to_streamed_response_wrapper(
            highlvl.fetch_payload_multiple,
        )
        self.get_detailed_target_groups = async_to_streamed_response_wrapper(
            highlvl.get_detailed_target_groups,
        )
        self.get_full_tg_list = async_to_streamed_response_wrapper(
            highlvl.get_full_tg_list,
        )
        self.get_task_status = async_to_streamed_response_wrapper(
            highlvl.get_task_status,
        )
        self.get_tg_names_only = async_to_streamed_response_wrapper(
            highlvl.get_tg_names_only,
        )
        self.list_load_balancers_by_vpc = async_to_streamed_response_wrapper(
            highlvl.list_load_balancers_by_vpc,
        )
        self.update_load_balancer = async_to_streamed_response_wrapper(
            highlvl.update_load_balancer,
        )
        self.update_target_group = async_to_streamed_response_wrapper(
            highlvl.update_target_group,
        )


from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["CertListParams"]


class CertListParams(TypedDict, total=False):
    vpc_id: Required[Annotated[str, PropertyInfo(alias="vpcId")]]

    lbtype: str


from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["PodUpdateParams"]


class PodUpdateParams(TypedDict, total=False):
    action: Required[Literal["start", "stop", "restart"]]
    """The action to perform on the kpod."""



from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from krutrim_client._utils import PropertyInfo




__all__ = ["AccessKeyCreateParams"]


class AccessKeyCreateParams(TypedDict, total=False):
    key_name: Required[str]
    """The name for the access key."""

    region: Required[str]
    """The region associated with the access key."""

    x_region_id: Required[Annotated[str, PropertyInfo(alias="x-region-id")]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .addons import (
    AddonsResource,
    AsyncAddonsResource,
    AddonsResourceWithRawResponse,
    AsyncAddonsResourceWithRawResponse,
    AddonsResourceWithStreamingResponse,
    AsyncAddonsResourceWithStreamingResponse,
)
from .clusters import (
    ClustersResource,
    AsyncClustersResource,
    ClustersResourceWithRawResponse,
    AsyncClustersResourceWithRawResponse,
    ClustersResourceWithStreamingResponse,
    AsyncClustersResourceWithStreamingResponse,
)
from .node_groups import (
    NodeGroupsResource,
    AsyncNodeGroupsResource,
    NodeGroupsResourceWithRawResponse,
    AsyncNodeGroupsResourceWithRawResponse,
    NodeGroupsResourceWithStreamingResponse,
    AsyncNodeGroupsResourceWithStreamingResponse,
)

__all__ = [
    "NodeGroupsResource",
    "AsyncNodeGroupsResource",
    "NodeGroupsResourceWithRawResponse",
    "AsyncNodeGroupsResourceWithRawResponse",
    "NodeGroupsResourceWithStreamingResponse",
    "AsyncNodeGroupsResourceWithStreamingResponse",
    "AddonsResource",
    "AsyncAddonsResource",
    "AddonsResourceWithRawResponse",
    "AsyncAddonsResourceWithRawResponse",
    "AddonsResourceWithStreamingResponse",
    "AsyncAddonsResourceWithStreamingResponse",
    "ClustersResource",
    "AsyncClustersResource",
    "ClustersResourceWithRawResponse",
    "AsyncClustersResourceWithRawResponse",
    "ClustersResourceWithStreamingResponse",
    "AsyncClustersResourceWithStreamingResponse",
]



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient


load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    create_bucket_resp = client.kos.buckets.create_bucket(
        name="enter the bucket name",  
        region="enter the region",     
        x_region_id="enter the region" 
        # x_region possible values "In-Bangalore-1","In-Hyderabad-1"
    )

    
    print(f"successfully created bucket: {create_bucket_resp}")

except Exception as e:
    print(f"Error has occurred: {e}")




import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient


load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    
    kpod_krn = "enter the pod krn"  
    action = "enter start or stop"  
    
    pod = client.kpod.pod.update(kpod_krn=kpod_krn, action=action)
    print(f"Pod with ID {kpod_krn} has been {action}ed successfully.")
    
except Exception as e:
    print(f"Error performing the action: {e}")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["V1PerformActionParams"]


class V1PerformActionParams(TypedDict, total=False):
    action: Required[Literal["stop", "stop", "reboot"]]
    """The action to perform on the VM instance."""



from .asgV1 import (
    V1Resource,
    AsyncV1Resource,
    V1ResourceWithRawResponse,
    AsyncV1ResourceWithRawResponse,
    V1ResourceWithStreamingResponse,
    AsyncV1ResourceWithStreamingResponse,
)
from .asg import (
    AsgResource,
    AsyncAsgResource,
    AsgResourceWithRawResponse,
    AsyncAsgResourceWithRawResponse,
    AsgResourceWithStreamingResponse,
    AsyncAsgResourceWithStreamingResponse,
)

__all__ = [
    "V1Resource",
    "AsyncV1Resource",
    "V1ResourceWithRawResponse",
    "AsyncV1ResourceWithRawResponse",
    "V1ResourceWithStreamingResponse",
    "AsyncV1ResourceWithStreamingResponse",
    "AsgResource",
    "AsyncAsgResource",
    "AsgResourceWithRawResponse",
    "AsyncAsgResourceWithRawResponse",
    "AsgResourceWithStreamingResponse",
    "AsyncAsgResourceWithStreamingResponse",
]


from __future__ import annotations

from .v1_perform_action_params import V1PerformActionParams as V1PerformActionParams
from .v1_perform_action_response import V1PerformActionResponse as V1PerformActionResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .vpc_add_params import VpcAddParams as VpcAddParams
from .vpc_remove_params import VpcRemoveParams as VpcRemoveParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ...._types import SequenceNotStr
from ...._utils import PropertyInfo

__all__ = ["NodeGroupCreateParams", "NodeRepairConfig", "RemoteAccess", "ScalingConfig"]


class NodeGroupCreateParams(TypedDict, total=False):
    disk_size: Annotated[int, PropertyInfo(alias="diskSize")]

    instance_types: Annotated[str, PropertyInfo(alias="instanceTypes")]

    name: str

    node_repair_config: Annotated[NodeRepairConfig, PropertyInfo(alias="nodeRepairConfig")]

    remote_access: Annotated[RemoteAccess, PropertyInfo(alias="remoteAccess")]

    scaling_config: Annotated[ScalingConfig, PropertyInfo(alias="scalingConfig")]

    subnets_krn: Annotated[str, PropertyInfo(alias="subnetsKrn")]


class NodeRepairConfig(TypedDict, total=False):
    enabled: bool


class RemoteAccess(TypedDict, total=False):
    source_security_groups_krns: Annotated[SequenceNotStr[str], PropertyInfo(alias="sourceSecurityGroupsKrns")]

    ssh_key_krn: Annotated[str, PropertyInfo(alias="sshKeyKrn")]


class ScalingConfig(TypedDict, total=False):
    desired_size: Annotated[int, PropertyInfo(alias="desiredSize")]

    max_size: Annotated[int, PropertyInfo(alias="maxSize")]

    min_size: Annotated[int, PropertyInfo(alias="minSize")]



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient
from krutrim_client.types.asg import VolumeParam
from krutrim_client.types.asg import PolicyParam


load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)

try:
    create_template = client.asg.v1.with_raw_response.create_launch_template(
        vpc_krn="Enter the VPC KRN ID",
        instance_name="Enter the instance name",
        instance_type="Enter the instance type",
        region="Enter the region",
        security_groups=[
            "Enter the Security Group Krn ID 1",
            "Enter the security group KRN ID 2 and so on",
        ],
        sshkey_name="Enter the ssh key name",
        user_data="Enter an executable boot time command ex: #!bash sdk.sh",
        volume_name="Enter the Volume Name",
        image_krn="Enter the Image KRN ID",
        vpc_name="Enter the VPC name",
        subnet_id="Enter the Subnet ID",
        template_name="Enter the Template name",
        volume_size=[
            VolumeParam(
                count=1,         #Enter the Volume Count
                volume_size=20,  #Enter the Volume Size
            ),
            VolumeParam(
                count=1,
                volume_size=20,
            ),
            # and add so on for multiple volumes selection
        ],

        policy=[
            PolicyParam(
                predefined_metric_specification={
                    "PredefinedMetricType": "AverageCPUUtilization"
                },
                up_scale_target_value=70,     #Enter the up scale target value
                down_scale_target_value=40,   #Enter the down scale target value
                scale_out_cooldown=10,        #Enter the scale out cooldown time in sec
                scale_in_cooldown=10,         #Enter the scale in cooldown time in sec
            ),

            # Scheduled
            PolicyParam(
                predefined_metric_type="PutScheduledAction",
                up_scale_time="Enter the upscale schedule time in format 07:00:00.000000",
                down_scale_time="Enter the downscale schedule time in format 22:00:00.000000",
            )
        ],
        volume_type="Enter the Volume Type",
        min=2,   #Enter the minimum instance count
        max=6,   #Enter the maximum instance count
    )
    print(create_template.json())

except Exception as e:
    print(f"Error has occurred: {e}")




# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .addon_install_params import AddonInstallParams as AddonInstallParams
from .node_group_create_params import NodeGroupCreateParams as NodeGroupCreateParams
from .node_group_upgrade_params import NodeGroupUpgradeParams as NodeGroupUpgradeParams



from __future__ import annotations

# from .image_list import ImageList as ImageList
from .vpc_detail import VpcDetail as VpcDetail
from .port_detail import PortDetail as PortDetail
from .instance_info import InstanceInfo as InstanceInfo
from .success_response import SuccessResponse as SuccessResponse
from .instance_info_list import InstanceInfoList as InstanceInfoList
from .highlvlvpc_create_vpc_params import HighlvlvpcCreateVpcParams as HighlvlvpcCreateVpcParams
from .highlvlvpc_delete_vpc_params import HighlvlvpcDeleteVpcParams as HighlvlvpcDeleteVpcParams
from .highlvlvpc_create_port_params import HighlvlvpcCreatePortParams as HighlvlvpcCreatePortParams
from .highlvlvpc_list_vpcs_response import HighlvlvpcListVpcsResponse as HighlvlvpcListVpcsResponse
from .highlvlvpc_search_vpcs_params import HighlvlvpcSearchVpcsParams as HighlvlvpcSearchVpcsParams
from .highlvlvpc_retrieve_vpc_params import HighlvlvpcRetrieveVpcParams as HighlvlvpcRetrieveVpcParams
from .highlvlvpc_search_ports_params import HighlvlvpcSearchPortsParams as HighlvlvpcSearchPortsParams
from .highlvlvpc_create_subnet_params import HighlvlvpcCreateSubnetParams as HighlvlvpcCreateSubnetParams
from .highlvlvpc_search_vpcs_response import HighlvlvpcSearchVpcsResponse as HighlvlvpcSearchVpcsResponse
from .highlvlvpc_search_ports_response import HighlvlvpcSearchPortsResponse as HighlvlvpcSearchPortsResponse
from .highlvlvpc_create_instance_params import HighlvlvpcCreateInstanceParams as HighlvlvpcCreateInstanceParams
from .highlvlvpc_delete_instance_params import HighlvlvpcDeleteInstanceParams as HighlvlvpcDeleteInstanceParams
from .highlvlvpc_search_networks_params import HighlvlvpcSearchNetworksParams as HighlvlvpcSearchNetworksParams
from .highlvlvpc_search_instances_params import HighlvlvpcSearchInstancesParams as HighlvlvpcSearchInstancesParams
from .highlvlvpc_retrieve_instance_params import HighlvlvpcRetrieveInstanceParams as HighlvlvpcRetrieveInstanceParams
from .highlvlvpc_search_networks_response import HighlvlvpcSearchNetworksResponse as HighlvlvpcSearchNetworksResponse
from .highlvlvpc_list_instance_info_params import HighlvlvpcListInstanceInfoParams as HighlvlvpcListInstanceInfoParams
from .highlvlvpc_get_vpc_task_status_params import HighlvlvpcGetVpcTaskStatusParams as HighlvlvpcGetVpcTaskStatusParams
from .highlvlvpc_create_image_params import HighlvlvpcCreateImageParams as HighlvlvpcCreateImageParams
from .highlvlvpc_create_image_response import HighlvlvpcCreateImageResponse as HighlvlvpcCreateImageResponse
from .highlvlvpc_list_image_params import HighlvlvpcListImageParams as HighlvlvpcListImageParams
from .highlvlvpc_list_image_response import HighlvlvpcListImageResponse as HighlvlvpcListImageResponse
from .highlvlvpc_delete_image_params import HighlvlvpcDeleteImageParams as HighlvlvpcDeleteImageParams
from .highlvlvpc_delete_machine_image_params import HighlvlvpcImageParams as HighlvlvpcImageParams
from .highlvlvpc_machine_s3_params import ImageMachineParams as ImageMachineParams
from .highlvlvpc_machine_s3_response import ImageMachineResponse as ImageMachineResponse


from .qos import Qos as Qos

from .qos_params import QosParam as QosParam


# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["SshkeyCreateParams"]


class SshkeyCreateParams(TypedDict, total=False):
    key_name: Required[Annotated[str, PropertyInfo(alias="keyName")]]
    """The name for the SSH key. Must be unique."""

    public_key: Required[Annotated[str, PropertyInfo(alias="publicKey")]]
    """The actual public SSH key string (e.g., starting with "ssh-rsa")."""





from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from krutrim_client._utils import PropertyInfo

__all__ = ["V1CreateRuleParams"]


class V1CreateRuleParams(TypedDict, total=False):
    direction: Required[Literal["ingress", "egress"]]
    """Direction of the rule."""

    ethertypes: Required[Literal["ipv4", "ipv6"]]
    """Ethertype of the rule."""

    port_max_range: Required[Annotated[int, PropertyInfo(alias="portMaxRange")]]
    """Maximum port in the range."""

    port_min_range: Required[Annotated[int, PropertyInfo(alias="portMinRange")]]
    """Minimum port in the range."""

    protocol: Required[str]
    """Protocol for the rule (e.g., tcp, udp, icmp, or 'any')."""

    remote_ip_prefix: Required[Annotated[str, PropertyInfo(alias="remoteIPPrefix")]]
    """Remote IP CIDR prefix for the rule."""

    vpcid: Required[str]
    """KRN of the VPC associated with the rule."""

    k_customer_id: Required[Annotated[str, PropertyInfo(alias="K-Customer-ID")]]

    x_account_id: Required[Annotated[str, PropertyInfo(alias="x-account-id")]]



from __future__ import annotations

from .bucket_create_params import BucketCreateParams as BucketCreateParams
from .bucket_list_response import BucketListResponse as BucketListResponse
from .bucket_create_response import BucketCreateResponse as BucketCreateResponse






from typing import List, Optional
from datetime import datetime

from ..._models import BaseModel

__all__ = ["PortDetail", "FixedIP"]


class FixedIP(BaseModel):
    ip_address: Optional[str] = None

    subnet_id: Optional[str] = None


class PortDetail(BaseModel):
    admin_state_up: Optional[bool] = None
    """Administrative state of the port."""

    created_at: Optional[datetime] = None
    """Timestamp of port creation."""

    device_id: Optional[str] = None
    """ID of the device that uses this port (e.g., VM ID)."""

    device_owner: Optional[str] = None
    """Entity that owns the port (e.g., network:dhcp, compute:nova)."""

    fixed_ips: Optional[List[FixedIP]] = None
    """List of fixed IP addresses assigned to the port."""

    floating_ip_address: Optional[str] = None
    """The floating IP address associated with the port, if any."""

    mac_address: Optional[str] = None
    """MAC address of the port."""

    name: Optional[str] = None
    """Name of the port."""

    network_id: Optional[str] = None
    """KRN of the network this port belongs to."""

    port_id: Optional[str] = None
    """The unique identifier or KRN of the created port."""

    security_group_krns: Optional[List[str]] = None
    """List of security group KRNs attached to this port."""

    status: Optional[str] = None
    """Current status of the port (e.g., ACTIVE, DOWN, BUILD)."""

    subnet_id: Optional[str] = None
    """KRN of the subnet this port is associated with."""

    updated_at: Optional[datetime] = None
    """Timestamp of last port update."""



import os
from dotenv import load_dotenv
from krutrim_client import KrutrimClient

load_dotenv()
api_key = os.getenv("API_KEY")
client = KrutrimClient(api_key=api_key)


try:
    downscale_asg = client.asg.v1.with_raw_response.downscale_asg(
        asg_krn = "Enter the asg KRN ID",
        count=1    #Enter the count of minimum Instances you want to reduce
    )

    print(f"{downscale_asg.json()}")

except Exception as e:
    print(f"Error has occurred: {e}")